@@ -18,7 +18,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 '''
 
-__version__ = '3.1.7'
+__version__ = '3.2.1'
 __author__ = 'Charles Cazabon <getmail @ discworld.dyndns.org>'
 
 #
@@ -48,6 +48,15 @@ from getmail_constants import *
 # Count of deliveries for getmail; used in Maildir delivery
 deliverycount = 0
 
+# Incompatible change in Python standard library in Python version 1.6;
+# session.retr() used to return the raw message lines, now it returns
+# the cooked (unstuffed) lines.  So we only unstuff for older versions of
+# Python now.
+if sys.hexversion < 0x01060000:
+    NEED_REMOVE_LEADING_DOTS = 1
+else:
+    NEED_REMOVE_LEADING_DOTS = 0
+  
 #
 # Classes
 #
@@ -199,7 +208,7 @@ class getmail:
                 rc = self.session.apop (self.conf['username'], self.conf['password'])
                 self.logfunc (INFO, '  POP3 APOP response:  %s\n' % rc)
             except SPDS_error_proto:
-                raise getmailConfigException, 'server does not support APOP'
+                raise getmailConfigException, 'error during attempted APOP authentication'
         else:
             rc = self.session.user (self.conf['username'])
             self.logfunc (INFO, '  POP3 user response:  %s\n' % rc)
@@ -404,7 +413,8 @@ class getmail:
             #cmd = popen2.Popen3 (command, 1, bufsize=-1)
             cmd = popen2.Popen3 (command, 1, bufsize=512)
             cmdout, cmdin, cmderr = cmd.fromchild, cmd.tochild, cmd.childerr
-            cmdin.write (fromline)
+            if self.conf['command_add_fromline']:
+                cmdin.write (fromline)
             cmdin.write (string.replace (msg, line_end['pop3'], line_end['mbox']))
             # Add trailing blank line
             cmdin.write ('\n')
@@ -565,7 +575,7 @@ class getmail:
                 self.logfunc (INFO, '  msg #%i/%i : len %s ... ' % (msgnum, len (self.msglist) - 1, msglen))
 
                 if msglen and self.conf['max_message_size'] and msglen > self.conf['max_message_size']:
-                    self.logfunc (INFO, 'over max message size of %(max_message_size)i, skipping ...\n')
+                    self.logfunc (WARN, 'over max message size of %(max_message_size)i, skipping ...\n')
                     continue
 
                 # Retrieve this message if:
@@ -576,7 +586,8 @@ class getmail:
                     rc, msglines, octets = self.session.retr (msgnum)
                     msg = string.join (msglines + [''], line_end['pop3'])
                     self.logfunc (INFO, 'retrieved')
-                    msg = pop3_unescape (msg)
+                    if NEED_REMOVE_LEADING_DOTS:
+                        msg = pop3_unescape (msg)
 
                     try:
                         # Find recipients for this message and deliver to them.
